@@ -1,5 +1,5 @@
-# from CTL.causal_tree.util import *
-from CTL.causal_tree.util_c import *
+from CTL.causal_tree.util import *
+# from CTL.causal_tree.util_c import *
 from CTL.causal_tree.causal_tree import *
 import numpy as np
 
